import { typescript } from 'projen'
const project = new typescript.TypeScriptProject({
  defaultReleaseBranch: 'main',
  name: 'projen-bitbucket-pipelines',
  projenrcTs: true,
  deps: [
    'projen',
    'glob',
    'fs-extra',
    'case',
  ],
  bundledDeps: [
    'glob@^7',
    'chalk@<5',
    'semver',
  ],
  devDeps: [
    '@types/fs-extra',
    '@types/glob',
    '@types/semver',
    'babel-jest',
    '@babel/core',
  ],
  minNodeVersion: '14.18.0',
  workflowNodeVersion: '14.18.0', // required by @typescript-eslint/eslint-plugin@5.19.0
  packageName: 'projen-bitbucket-pipeline',
  releaseFailureIssue: true,
  repository: 'https://github.com/ajbell-uk/projen-bitbucket-pipelines',
  tsconfig: {
    compilerOptions: {
      baseUrl: '.',
      esModuleInterop: true,
      allowJs: true,
      paths: {
        '@src/*': ['src/*'],
        '@test/*': ['test/*'],
      },
    },
  },
  jestOptions: {
    jestConfig: {
      preset: 'ts-jest/presets/js-with-ts',
      transform: {},
      moduleNameMapper: {
        '@src/(.*)$': '<rootDir>/src/$1',
        '@test/(.*)$': '<rootDir>/test/$1',
      },
    },
  },
  codeCov: true,
  autoMerge: true,
  release: true,
  dependabot: true,
  docgen: true,
  releaseToNpm: true,
  codeCovTokenSecret: 'CODECOV',
})

project.eslint?.addOverride({
  files: [
    '.projenrc.ts',
    'src/**/*.+(ts|tsx)',
    'test/**/*.+(ts|tsx)',
    'tools/**/*.+(ts|tsx)',
  ],
  rules: {
    'semi': [
      'error',
      'never',
    ],
    '@typescript-eslint/member-delimiter-style': [
      'error', {
        multiline: {
          delimiter: 'none', // 'none' or 'semi' or 'comma'
          requireLast: true,
        },
        singleline: {
          delimiter: 'semi', // 'semi' or 'comma'
          requireLast: false,
        },
      },
    ],
    'eol-last': ['error', 'always'],
  },
})

const tsconfigJson = project.tryFindObjectFile('tsconfig.dev.json')
if (tsconfigJson) {
  tsconfigJson.addOverride('ts-node', {
    require: ['tsconfig-paths/register'],
    compilerOptions: {
      module: 'commonjs',
    },
  })
}

project.synth()
