/**
 * Used to define caches used during build steps.
 * @see https://support.atlassian.com/bitbucket-cloud/docs/databases-and-service-containers/
 */
export interface PipelineOptions {
    maxTime?: number;
}
/**
 * Used to define caches used during build steps.
 * @see https://support.atlassian.com/bitbucket-cloud/docs/databases-and-service-containers/
 */
export interface Caches {
    docker?: boolean;
    composer?: boolean;
    dotnetcore?: boolean;
    gradle?: boolean;
    ivy2?: boolean;
    maven?: boolean;
    node?: boolean;
    pip?: boolean;
    sbt?: boolean;
    custom?: {
        [name: string]: string;
    };
}
/**
 * Used to define images to used during build steps.
 * @see https://support.atlassian.com/bitbucket-cloud/docs/databases-and-service-containers/
 */
export interface Service {
    /** Docker image name/uri.*/
    readonly image: string;
    /** Docker variables to be passed into the container.*/
    readonly variables?: {
        [name: string]: string;
    };
}
export declare class Definitions {
    readonly services?: Record<string, Service>;
    readonly caches?: Caches;
}
/**
 * Steps are the most fundamental element of a bitbucket-pipeline.yml file.
 * @see https://support.atlassian.com/bitbucket-cloud/docs/configure-bitbucket-pipelinesyml/#Steps
 */
export interface Step {
    /** Step name.*/
    readonly name?: string;
    /** Shell scripts executed in the step.*/
    readonly script?: string[];
}
export declare class Pipeline {
    readonly step?: Step[];
}
/**
 * Define the pipelines
 * @see https://support.atlassian.com/bitbucket-cloud/docs/databases-and-service-containers/
 */
export interface Pipelines {
    readonly definitions?: Definitions;
    readonly custom?: Record<string, Pipeline>;
    readonly default?: Record<string, Pipeline>;
    readonly branches?: Record<string, Pipeline>;
    readonly tags?: Record<string, Pipeline>;
    readonly pullRequests?: Record<string, Pipeline>;
}
