import { Component, Project, YamlFile } from 'projen';
import { Definitions, Pipelines, PipelineOptions, Service } from './configuration-model';
/**
 * Options for `PipelineConfiguration`.
 */
export interface PipelineConfigurationOptions {
    readonly definitions?: Definitions;
    readonly options?: PipelineOptions;
    readonly pipelines?: Pipelines;
}
/**
 * Pipeline for Bitbucket.
 * A Pipeline is a configurable automated process made up of one or more steps/jobs.
 * @see https://support.atlassian.com/bitbucket-cloud/docs/configure-bitbucket-pipelinesyml/
 */
export declare class PipelineConfiguration extends Component {
    /**
     * The project the configuration belongs to.
     */
    readonly project: Project;
    /**
     * The name of the configuration.
     */
    readonly name: string;
    /**
     * Path to CI file generated by the configuration.
     */
    readonly path: string;
    /**
     * The workflow YAML file.
     */
    readonly file: YamlFile;
    readonly definitions: Definitions;
    readonly options: PipelineOptions;
    readonly pipelines: Pipelines;
    constructor(project: Project, name: string, options?: PipelineConfigurationOptions);
    /**
     * Add additional services.
     * @param services The services to add.
     */
    addServices(services: Record<string, Service>): void;
    private renderPipelineConfiguration;
    private renderCaches;
    private renderOptions;
    private renderPipelines;
}
